@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2003 Ghostgum Software Pty Ltd.  All rights reserved.
+/* Copyright (C) 2001-2005 Ghostgum Software Pty Ltd.  All rights reserved.
 
   This software is provided AS-IS with no warranty, either express or
   implied.
@@ -13,7 +13,7 @@
   Fax +61 3 9886 6616.
 */
 
-/* $Id: cimg.h,v 1.14 2004/07/08 09:13:54 ghostgum Exp $ */
+/* $Id: cimg.h,v 1.16 2005/06/10 09:39:24 ghostgum Exp $ */
 /* Image information and format conversions header */
 
 /***************************************/
@@ -119,6 +119,13 @@ void image_16BGR555_to_24RGB(int width, unsigned char *dest, unsigned char *sour
 int image_merge_cmyk(IMAGE *img, IMAGE *layer, float cyan, float magenta,
    float yellow, float black);
 int image_down_scale(IMAGE *newimg, IMAGE *oldimg);
+/* use_85 parameter */
+#define IMAGE_ENCODE_HEX 0
+#define IMAGE_ENCODE_ASCII85 1
+/* compress parameter */
+#define IMAGE_COMPRESS_NONE 0
+#define IMAGE_COMPRESS_RLE 1
+#define IMAGE_COMPRESS_LZW 2
 int image_to_eps(GFile *f, IMAGE *img, int llx, int lly, int urx, int ury,
     float fllx, float flly, float furx, float fury, int use_a85, int compress);
 int image_to_epsfile(IMAGE *img, LPCTSTR filename, float xdpi, float ydpi);
